package com.example.controller;

import com.example.domain.Owner;
import com.example.domain.Pet;
import com.example.domain.PetType;
import com.example.repository.OwnerRepository;
import com.example.repository.PetRepository;
import io.micronaut.http.annotation.Controller;
import io.micronaut.http.annotation.Get;
import io.micronaut.transaction.annotation.Transactional;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@Controller("/init")
class InitController {
    private final OwnerRepository ownerRepository;
    private final PetRepository petRepository;

    InitController(OwnerRepository ownerRepository, PetRepository petRepository) {
        this.ownerRepository = ownerRepository;
        this.petRepository = petRepository;
    }

    @Get
    @Transactional
    Mono<Void> init() {
        Owner fred = ownerRepository.create();
        fred.setName("Fred");
        fred.setAge(45);
        Owner barney = ownerRepository.create();
        barney.setName("Barney");
        barney.setAge(40);

        Pet dino = petRepository.create();
        dino.setName("Dino");
        dino.setOwner(fred);
        Pet bp = petRepository.create();
        bp.setName("Baby Puss");
        bp.setOwner(fred);
        bp.setType(PetType.CAT);
        Pet hoppy = petRepository.create();
        hoppy.setName("Hoppy");
        hoppy.setOwner(barney);

        return Flux.concat(
            ownerRepository.save(fred),
            ownerRepository.save(barney),
            petRepository.save(dino),
            petRepository.save(bp),
            petRepository.save(hoppy)
        ).then();
    }

}
