package com.example.controller;

import com.example.dto.OwnerDto;
import com.example.repository.OwnerRepository;
import io.micronaut.http.annotation.Controller;
import io.micronaut.http.annotation.Get;
import io.micronaut.transaction.annotation.Transactional;
import reactor.core.publisher.Mono;

import java.util.List;

@Controller("/owners")
class OwnerController {

    private final OwnerRepository ownerRepository;
    private final Mapper mapper;

    OwnerController(OwnerRepository ownerRepository, Mapper mapper) {
        this.ownerRepository = ownerRepository;
        this.mapper = mapper;
    }

    @Get
    @Transactional(readOnly = true)
    Mono<List<OwnerDto>> all() {
        return ownerRepository.findAll()
                .map(mapper::toOwnerDto)
            .collectList();
    }

    @Get("/{name}")
    @Transactional(readOnly = true)
    Mono<OwnerDto> byName(String name) {
        return ownerRepository.findByName(name)
                .map(mapper::toOwnerDto);
    }

}
