package com.example.controller;

import com.example.dto.PetDto;
import com.example.repository.PetRepository;
import io.micronaut.http.annotation.Controller;
import io.micronaut.http.annotation.Get;
import io.micronaut.transaction.annotation.Transactional;
import reactor.core.publisher.Mono;

import java.util.List;

@Controller("/pets")
class PetController {

    private final PetRepository petRepository;
    private final Mapper mapper;

    PetController(PetRepository petRepository, Mapper mapper) {
        this.petRepository = petRepository;
        this.mapper = mapper;
    }

    @Transactional(readOnly = true)
    @Get
    Mono<List<PetDto>> all() {
        return petRepository.findAll()
            .map(mapper::toPetDto)
            .collectList();
    }

    @Transactional(readOnly = true)
    @Get("/{name}")
    Mono<PetDto> byName(String name) {
        return petRepository.findByName(name).map(mapper::toPetDto);
    }

}
